const { genNamedExport, genImport } = require("./utils");

module.exports = (
  file,
  api,
  { from, default: defaultImport, importList: _importList }
) => {
  const j = api.jscodeshift;
  const importList = _importList ?? [];
  const root = j(file.source);

  // inject import
  const newImport = genImport(j, from, defaultImport, ...importList);

  root.nodes()[0].program.body.unshift(newImport);

  const installNode = root.find(j.FunctionDeclaration, (node) => {
    if (node.id.name === "install") {
      return true;
    }
  });

  // inject install
  const newExpress = j.expressionStatement(
    j.callExpression(
      j.memberExpression(j.identifier("app"), j.identifier("use")),
      [j.identifier(defaultImport)]
    )
  );
  installNode.nodes()[0].body.body.push(newExpress);

  // inject export
  const exportNode = root.find(j.ExportNamedDeclaration, (node) => {
    return true;
  });

  if (importList.length) {
    exportNode.nodes()[0].specifiers.push(
      ...importList.map((namedImport) => {
        return genNamedExport(j, namedImport);
      })
    );
  }

  return root.toSource();
};
